@@ -2,8 +2,7 @@ import click
 import pyfiglet
 
 from .. import profile_configurator, login_processor
-from ..client.actionsImpl import ActionsImpl
-from ..constants.constants import Formats
+from ..constants.constants import Formats, Export_Formats
 from ..processors.addons.addons import Addons
 from ..processors.addresses.address import Address
 from ..processors.cards.card import Card
@@ -15,6 +14,7 @@ from ..processors.credit_notes.credit_note import CreditNote
 from ..processors.customer.customer import Customer
 from ..processors.events.events import Event
 from ..processors.exports.export import Export
+from ..processors.gifts.gifts import Gift
 from ..processors.hosted_pages.hosted_pages import HostedPage
 from ..processors.invoices.invoice import Invoice
 from ..processors.order.order import Order
@@ -116,12 +116,16 @@ def login(ctx, profile):
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.option('--columns', '-cols', nargs=0, required=False, help="columns to be printed in output")
 @click.argument('columns', nargs=-1)
-def plan(ctx, id, operation, columns, format, name, invoice_name, price):
-    payload = {'id': id, 'name': name, 'invoice_name': invoice_name, 'price': price}
-    Plan() \
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def plan(ctx, id, operation, columns, format, name, invoice_name, price, export_filename, export_format, export_path):
+    Plan(export_format=export_format, export_path=export_path, file_name=export_filename) \
         .validate_param(columns) \
-        .process(None, operation, payload=payload, resource_id=id) \
-        .format(format, operation)
+        .process(None, operation, payload=None, resource_id=id) \
+        .format(format, operation) \
+        .export_data()
     ctx.exit()
 
 
@@ -142,8 +146,11 @@ def process_result(result):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def addon(ctx, id, operation, columns, format):
-
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def addon(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Addons() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -163,7 +170,11 @@ def addon(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def coupon(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def coupon(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Coupons() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -182,7 +193,11 @@ def coupon(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def customer(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def customer(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Customer() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -220,11 +235,11 @@ def export(ctx, id, operation, columns, format):
               cls=MultipleColumns)
 @click.option('--columns-cus', "-c", nargs=-1, required=False, help="columns to be printed in output",
               cls=MultipleColumns)
-# @click.option('--columns-subs', '-cols-subs', nargs=0, required=False, help="columns to be printed in output")
-# @click.argument('columns-subs', nargs=-1)
-# @click.option('--columns-customer', '-cols-cus',nargs=0, type=(), required=False, help="columns to be printed in
-# output") @click.argument('columns-customer', nargs=-1)
-def subscription(ctx, id, operation, columns_subs, columns_cus, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def subscription(ctx, id, operation, columns_subs, columns_cus, format, export_filename, export_format, export_path):
     Subscription(columns_subs, columns_cus, operation) \
         .validate_param(columns_subs) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -244,7 +259,11 @@ def subscription(ctx, id, operation, columns_subs, columns_cus, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def cards(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def cards(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Card() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -260,7 +279,11 @@ def cards(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def promotional_credits(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def promotional_credits(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     PromotionalCredit() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -276,7 +299,11 @@ def promotional_credits(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def invoice(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def invoice(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Invoice() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -292,7 +319,11 @@ def invoice(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def credit_note(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def credit_note(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     CreditNote() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -308,7 +339,11 @@ def credit_note(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def unbilled_charges(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def unbilled_charges(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     UnbilledCharge() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -324,7 +359,11 @@ def unbilled_charges(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def order(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def order(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Order() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -340,8 +379,12 @@ def order(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def order(ctx, id, operation, columns, format):
-    Order() \
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def gift(ctx, id, operation, columns, format, export_filename, export_format, export_path):
+    Gift() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
         .format(format, operation)
@@ -356,7 +399,11 @@ def order(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def txn(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def txn(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Transaction() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -372,7 +419,11 @@ def txn(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def hosted_pages(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def hosted_pages(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     HostedPage() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -388,7 +439,11 @@ def hosted_pages(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def quote(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def quote(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Quote() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -404,7 +459,11 @@ def quote(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def coupon_set(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def coupon_set(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     CouponSet() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -420,7 +479,11 @@ def coupon_set(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def coupon_code(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def coupon_code(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     """ endpoint to perform operation on coupon resources."""
     if operation == 'archive':
         operation = 'delete'
@@ -440,7 +503,11 @@ def coupon_code(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def address(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def address(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Address() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -456,7 +523,11 @@ def address(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def event(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def event(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Event() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
@@ -472,7 +543,11 @@ def event(ctx, id, operation, columns, format):
 @click.option("--format", "-f", required=False,
               help="this allows user to format the output in json or table format..", default=Formats.TABLE.name)
 @click.argument('columns', nargs=-1)
-def comment(ctx, id, operation, columns, format):
+@click.option('--export-format', "-ef", help='data to be imported in [csv / excel / html',
+              default=Export_Formats.CSV.value, type=str)
+@click.option('--export-filename', "-efn", help='name of exported file', type=str)
+@click.option('--export-path', "-ep", help='path where file to be exported', type=click.Path(exists=True))
+def comment(ctx, id, operation, columns, format, export_filename, export_format, export_path):
     Comment() \
         .validate_param(columns) \
         .process(None, operation, payload=None, resource_id=id) \
