@@ -17,3 +17,15 @@ class ApiOperation(enum.Enum):
 class Profile(enum.Enum):
     API_KEY = 'api_key'
     ACCOUNT = 'account'
+
+
+class Export_Formats(enum.Enum):
+    CSV = 'csv'
+    EXCEL = 'excel'
+    HTML = 'html'
+
+
+class Export_Formats_Extensions(enum.Enum):
+    CSV = '.csv'
+    EXCEL = '.xlsx'
+    HTML = '.html'
