@@ -1,4 +1,5 @@
 from chargebeecli.client.actionsImpl import ActionsImpl
+from chargebeecli.export.Exporter import Exporter
 from chargebeecli.printer import Printer
 from chargebeecli.processor import Processor
 from chargebeecli.response_formatter import ResponseFormatter
@@ -7,7 +8,7 @@ from chargebeecli.validator import Validator
 API_URI = '/api/v2/events'
 
 
-class Event(Processor, Validator, ResponseFormatter, Printer):
+class Event(Processor, Validator, ResponseFormatter, Printer, Exporter):
     __action_processor = ActionsImpl()
 
     def __init__(self):
@@ -37,3 +38,12 @@ class Event(Processor, Validator, ResponseFormatter, Printer):
     def delete(self, ctx, payload, resource_id):
         print('delete: operation is not supported for addresses')
         exit()
+
+
+    def to_be_exported(self):
+        return self.export_format and self.export_path and self.file_name
+
+    def export_data(self):
+        if self.to_be_exported():
+            Exporter(self.headers, self.tables).export(_path=self.export_path, _export_format=self.export_format,
+                                                       _file_name=self.file_name)
\ No newline at end of file
